#
# spec file for package hbci4java
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{!?make_build:%global make_build make %{?_smp_mflags}}
Name:           hbci4java
Version:        3.1.79
Release:        1.2
Summary:        Java online banking client using the HBCI standard
License:        LGPL-2.1-only
Group:          Productivity/Office/Finance
URL:            https://github.com/hbci4j/hbci4java
Source:         https://github.com/hbci4j/hbci4java/archive/refs/tags/hbci4j-core-%{version}.tar.gz
Patch0:         signed-char.patch
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  java-devel >= 8
BuildRequires:  maven-local
BuildRequires:  mvn(javax.xml.bind:jaxb-api)
BuildRequires:  mvn(org.glassfish.jaxb:jaxb-runtime)
BuildRequires:  mvn(org.jvnet.jaxb2.maven2:maven-jaxb22-plugin)

%description
Fork of HBCI4Java that contains support for chipTAN,
smsTAN, HHD, SEPA and other fixes/enhancements.

%package javadoc
Summary:        Javadoc for %{name}
Group:          Documentation/HTML
BuildArch:      noarch

%description javadoc
Developer documentation of HBCI4Java.

%prep
%setup -q -n %{name}-hbci4j-core-%{version}
%patch -P 0 -p1

# remove prebuilt binaries
rm server/*-bin.zip
rm chipcard/lib/*

# No need of this plugins for rpm build
%pom_remove_plugin :maven-javadoc-plugin
%pom_remove_plugin :maven-source-plugin
%pom_remove_plugin :nexus-staging-maven-plugin

%build
pushd chipcard
%make_build
popd

%{mvn_build} -f -- \
    -Dproject.build.outputTimestamp=$(date -u -d @${SOURCE_DATE_EPOCH:-$(date +%%s)} +%%Y-%%m-%%dT%%H:%%M:%%SZ)

%install
%mvn_install
install -Dm0644 chipcard/lib/*.so %{buildroot}%{_jnidir}/%{name}
%fdupes -s %{buildroot}%{_javadocdir}

%files -f .mfiles
%license LICENSE
%{_jnidir}/%{name}/*.so

%files javadoc -f .mfiles-javadoc
%license LICENSE

%changelog
* Wed Apr 10 2024 Fridrich Strba <fstrba@suse.com>
- update to 3.1.79
  * DECOUPLED nicht mehr als Default-Version und TAN-Prozess S
    nur bei HKTAN ab Version 7
  * Fallback auf HHDVersion.DEFAULT/DECCOUPLED, wenn nichts
    angegeben ist. Gehe davon aus, dass das das TAN-Verfahren der
    Zukunft bei den Banken ist.
  * Bei der Dialoginitialisierung mit SCA und HKTAN7 per Decoupled
    wurde im DE "TAN-Prozess" versehentlich "2" statt "S" gesendet.
    Die Ermittlung, ob "S" verwenden muss, passierte, nachdem die
    Nachricht bereits erstellt wurde.
  * In DialogInitSCA fehlte das TAN2Step7 sodass bei HTKTAN-Version
    7 gar kein HKTAN mitgesendet wurde.
  * Erweitertes Logging bei der SCA
  * see https://github.com/hbci4j/hbci4java/compare/hbci4j-core-3.1.76...hbci4j-core-3.1.79
* Wed Mar 20 2024 Fridrich Strba <fstrba@suse.com>
- update to 3.1.76
  * fix: Das Element "SchmeNm" wurde vergessen, zum Dokument
    hinzuzufügen.
  * required by hibiscus 2.10.18
  * see https://github.com/hbci4j/hbci4java/compare/hbci4j-core-3.1.75...hbci4j-core-3.1.76
* Wed Mar  6 2024 Fridrich Strba <fstrba@suse.com>
- update to 3.1.75
  * required by hibiscus 2.10.17
  * see https://github.com/hbci4j/hbci4java/compare/hbci4j-core-3.1.74...hbci4j-core-3.1.75
* Wed Feb 28 2024 Fridrich Strba <fstrba@suse.com>
- update to 3.1.74
  * required by hibiscus 2.10.16
  * see https://github.com/hbci4j/hbci4java/compare/hbci4j-core-3.1.64...hbci4j-core-3.1.74
* Wed Feb 21 2024 Gus Kenion <gus.kenion@suse.com>
- Use %%patch -P N instead of deprecated %%patchN.
* Wed Sep 13 2023 Fridrich Strba <fstrba@suse.com>
- Reproducible builds: use SOURCE_DATE_EPOCH for timestamp
* Tue Dec  6 2022 Dirk Müller <dmueller@suse.com>
- update to 3.1.64:
  * various BLZ updates
  * see https://github.com/hbci4j/hbci4java/compare/hbci4j-core-3.1.55...hbci4j-core-3.1.64
* Wed Jul 28 2021 Fridrich Strba <fstrba@suse.com>
- Define %%%%make_build for systems that don't have it defined in
  rpm macros
* Mon May  3 2021 Matthias Mailänder <mailaender@opensuse.org>
- update to version 3.1.55
* Wed Feb 17 2021 Matthias Mailänder <mailaender@opensuse.org>
- update to version 3.1.53
- build with maven-local
- Removed patches:
  * hbci4java-jdk10.patch
  * hbci4java-jdk9.patch
    + not needed with maven build
* Tue Jan 28 2020 Fridrich Strba <fstrba@suse.com>
- Require java-devel >= 1.8 in order to support nativeheaders
  directive
* Mon Mar  5 2018 schwab@suse.de
- signed-char.patch: fix conflicting char signedness
* Fri Dec 22 2017 fstrba@suse.com
- Added patch:
  * hbci4java-jdk10.patch
    + Fix build with jdk10 by not using javah
* Mon Sep 18 2017 fstrba@suse.com
- Modified file:
  * build.xml
- Added patch:
  * hbci4java-jdk9.patch
    + Specify java source and target 1.6 to allow building with
    jdk9
* Sat Nov 19 2016 mailaender@opensuse.org
- update to version 2.5.12 Hibiscus 2.6.18 build 361
* Sat Jul  9 2016 mailaender@opensuse.org
- update to version 2.5.12 Hibiscus 2.6.17 build 361
- license changed: https://github.com/willuhn/hbci4java/issues/36
* Wed Apr 20 2016 mailaender@opensuse.org
- update to version 2.5.12 Hibiscus 2.6.15 build 361
* Mon Dec 28 2015 mailaender@opensuse.org
- initial packaging
